django_auxilium.forms.multiple_values module
============================================

.. automodule:: django_auxilium.forms.multiple_values
    :members:
    :undoc-members:
    :show-inheritance:
